@@ -435,7 +435,7 @@ class BoundMethod(UnboundMethod):
         needs to be a tuple of classes
         """
         # pylint: disable=import-outside-toplevel; circular import
-        from astroid import node_classes
+        from astroid.nodes import node_classes
 
         # Verify the metaclass
         try:
