@@ -4,8 +4,8 @@
 # Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
 # Copyright (c) 2018 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2021 Alphadelta14 <alpha@alphaservcomputing.solutions>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Alphadelta14 <alpha@alphaservcomputing.solutions>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
@@ -22,7 +22,7 @@ leads to an inferred FrozenSet:
 """
 
 
-from astroid import bases, decorators, node_classes, scoped_nodes, util
+from astroid import bases, decorators, util
 from astroid.const import BUILTINS
 from astroid.exceptions import (
     AttributeInferenceError,
@@ -31,6 +31,7 @@ from astroid.exceptions import (
     SuperError,
 )
 from astroid.manager import AstroidManager
+from astroid.nodes import node_classes, scoped_nodes
 
 objectmodel = util.lazy_import("interpreter.objectmodel")
 
